@@ -10,7 +10,7 @@ import html
 from collections import namedtuple, OrderedDict
 import math
 
-__version__ = '0.18.1'
+__version__ = '0.18.2'
 __author__ = 'Danny Lin'
 __author_email__ = 'danny0838@gmail.com'
 __homepage__ = 'https://github.com/danny0838/sts-lib'
@@ -251,7 +251,7 @@ class StsDict():
             with open(file, "r", encoding="UTF-8") as f:
                 for line in f:
                     try:
-                        key, values, *_ = line.strip().split("\t")
+                        key, values, *_ = line.rstrip('\n').split("\t")
                     except ValueError:
                         pass
                     else:
@@ -549,42 +549,33 @@ class StsDict():
         """Helper function of apply_enum
         """
         (parts, matched, index) = data
-        match = self.match(parts, index)
-
-        # add atomic stepping if no match
-        if match is None:
-            stack.append((parts, matched, index + 1))
-            return
-
         has_atomic_match = False
-        if match.end - index == 1:
-            has_atomic_match = True
-        if include_self:
-            match_key = ''.join(match.conv.key)
-            if match_key not in match.conv.values:
-                match.conv.values.append(match_key)
-        for value in match.conv.values:
-            result = parts[:index] + [value] + parts[match.end:]
-            stack.append((result, matched + 1, index + 1))
+        i = math.inf
+        while i > index:
+            match = self.match(parts, index, maxlen=i)
 
-        if not include_short:
-            return
+            if match is None:
+                break
 
-        # add shorter matches
-        for i in range(match.end - match.start - 1, 0, -1):
-            match = self.match(parts, index, maxlen=index + i)
-            if match is not None:
-                if match.end - index == 1:
-                    has_atomic_match = True
-                if include_self:
-                    match_key = ''.join(match.conv.key)
-                    if match_key not in match.conv.values:
-                        match.conv.values.append(match_key)
-                for value in match.conv.values:
+            if match.end - index == 1:
+                has_atomic_match = True
+
+            for value in match.conv.values:
+                result = parts[:index] + [value] + parts[match.end:]
+                stack.append((result, matched + 1, index + 1))
+
+            if include_self:
+                value = ''.join(match.conv.key)
+                if value not in match.conv.values:
                     result = parts[:index] + [value] + parts[match.end:]
                     stack.append((result, matched + 1, index + 1))
 
-        # add atomic stepping (length = 1) case
+            if not include_short:
+                return
+
+            i = match.end - 1
+
+        # add atomic stepping (length = 1) case if none
         #
         # e.g.
         # table: 采信 => 採信, 信息 => 訊息
